@@ -1,5 +1,7 @@
 from textwrap import dedent
 
+import pytest
+
 from testfixtures import Comparison as C, ShouldRaise, should_raise
 from unittest import TestCase
 
@@ -35,6 +37,21 @@ class TestShouldAssert:
                 +bar
                 +assert False""")
 
+    def test_show_whitespace(self):
+        try:
+            with ShouldAssert('foo ', show_whitespace=True):
+                assert False, ' foo'
+        except AssertionError as e:
+            assert str(e) == dedent(
+                """\
+                --- expected
+                +++ actual
+                @@ -1 +1,2 @@
+                -'foo '
+                +' foo\\n'
+                +'assert False'"""
+            )
+
 
 
 class TestShouldRaise(TestCase):
@@ -205,7 +222,7 @@ class TestShouldRaise(TestCase):
 
     def test_import_errors_1(self):
         with ShouldRaise(ModuleNotFoundError("No module named 'textfixtures'")):
-            import textfixtures.foo.bar
+            import textfixtures.foo.bar  # type: ignore[import-not-found]
 
     def test_import_errors_2(self):
         with ShouldRaise(ImportError('X')):
@@ -301,4 +318,24 @@ class TestShouldRaise(TestCase):
             with ShouldRaise(MessageError('foo')):
                 raise MessageError('foo', None)
 
+    def test_exception_group_okay(self):
+        with ShouldRaise(ExceptionGroup('foo', [Exception('bar')])):
+            raise ExceptionGroup('foo', [Exception('bar')])
+
+    def test_exception_group_different(self):
+        with ShouldAssert(
+                "exception group not as expected:\n\n"
+                "While comparing msg: 'fob' (expected) != 'foo' (raised)\n\n"
+                "While comparing excs: sequence not as expected:\n\n"
+                "same:\n"
+                "[]\n\n"
+                "expected:\n"
+                "[Exception('baz')]\n\n"
+                "raised:\n"
+                "[Exception('bar')]\n\n"
+                "While comparing excs[0]: "
+                "Exception('baz') (expected) != Exception('bar') (raised)"
+        ):
+            with ShouldRaise(ExceptionGroup('fob', [Exception('baz')])):
+                raise ExceptionGroup('foo', [Exception('bar')])
 
